@@ -151,7 +151,7 @@ sub search_by_dns {
       if ref {} ne ref $cond or !exists $cond->{dns};
 
     (my $suffix = (delete $cond->{suffix} || ''))
-      =~ s|\Q(?^\Eu?|(?|g;
+      =~ s|\Q(?^\E[-xismu]*|(?|g;
 
     $cond->{dns} = [ -and =>
       { '-ilike' => delete $cond->{dns} },
